@@ -2,7 +2,7 @@
  * input_interface.h: Input functions usable outside input code.
  *****************************************************************************
  * Copyright (C) 1998-2008 VLC authors and VideoLAN
- * $Id: 0ec778cfdc027dd42ed8144b62d2c143b8273993 $
+ * $Id: b5f9795bd9e44a953a5d9df077078b9c43ba491d $
  *
  * Authors: Laurent Aimar < fenrir _AT_ videolan _DOT_ org >
  *
@@ -34,7 +34,10 @@ void input_item_SignalPreparseEnded( input_item_t *p_i, int new_status );
 void input_item_SetPreparsed( input_item_t *p_i, bool b_preparsed );
 void input_item_SetArtNotFound( input_item_t *p_i, bool b_not_found );
 void input_item_SetArtFetched( input_item_t *p_i, bool b_art_fetched );
-void input_item_SetEpg( input_item_t *p_item, const vlc_epg_t *p_epg );
+void input_item_SetEpg( input_item_t *p_item, const vlc_epg_t *p_epg, bool );
+void input_item_ChangeEPGSource( input_item_t *p_item, int i_source_id );
+void input_item_SetEpgEvent( input_item_t *p_item, const vlc_epg_event_t *p_epg_evt );
+void input_item_SetEpgTime( input_item_t *, int64_t );
 void input_item_SetEpgOffline( input_item_t * );
 
 /**
